#
# $Header:$
#

package Gnome2::ZvtTerm;

# Gtk uses unicode strings; thus we require perl>=5.8.x,
# which is unicode internally.
use 5.008;
use strict;
use warnings;
use AutoLoader;
require Exporter;
use Carp;

use Gtk2;

require DynaLoader;

our $VERSION = '0.3';

our @ISA = qw(Exporter DynaLoader);

our @EXPORT = qw(
	ZVT_TERM_DO_UTMP_LOG
	ZVT_TERM_DO_WTMP_LOG
	ZVT_TERM_DO_LASTLOG
	ZVT_BACKGROUND_SHADED
	ZVT_BACKGROUND_SCROLL
);

sub dl_load_flags { 0x01 }

# now load the XS code.
bootstrap Gnome2::ZvtTerm $VERSION;

# Preloaded methods go here.

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.

    my $constname;
    our $AUTOLOAD;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    croak "&Foo::constant not defined" if $constname eq 'constant';
    my ($error, $val) = constant($constname);
    if ($error) { croak $error; }
    {
	no strict 'refs';
	# Fixed between 5.005_53 and 5.005_61
#XXX	if ($] >= 5.00561) {
#XXX	    *$AUTOLOAD = sub () { $val };
#XXX	}
#XXX	else {
	    *$AUTOLOAD = sub { $val };
#XXX	}
    }
    goto &$AUTOLOAD;
}


1;
__END__
# documentation is a good thing.  write some.

=head1 NAME

Gnome2::ZvtTerm - Perl interface to the 2.x series of Zed's Virtual Terminal library

=head1 SYNOPSIS

  use Gnome2::ZvtTerm;
  Gtk2->init;
  use constant TRUE  => 1;
  use constant FALSE => 0;

  $window = Gtk2::Window->new;
  $window->signal_connect (delete_event => sub {
          $term->closepty;
          Gtk2->main_quit;
          FALSE
  });

  $term = Gnome2::ZvtTerm->new_with_size (80, 24);
  $vsb = Gtk2::VScrollbar->new ($term->adjustment);

  $hbox = Gtk2::HBox->new;
  $window->add ($hbox);
  $hbox->pack_start ($term, TRUE, TRUE, 0);
  $hbox->pack_start ($vsb, FALSE, FALSE, 0);

  $pid = $term->forkpty (FALSE);
  if ($pid == 0) {
          $ENV{COLUMNS} = 80;
          $ENV{ROWS} = 24;
          $ENV{TERM} = 'xterm';
          exec 'bash';
  }
  # destroy the window when the client exits.
  $term->signal_connect (child_died => sub {
          $window->destroy;
          Gtk2->main_quit;
  });

  $window->show_all;
  Gtk2->main;

=head1 DESCRIPTION

Zed's Virtual Terminal is a fast terminal emulator library that was part
of the Gnome 1.x desktop; this module provides the Perl developer with access
to the Gtk2 port of libzvt.

=head2 Exports

Unlike most gtk2-perl modules, this module exports some traditional constants
rather than using the string-based enums and flags (because libzvt doesn't
support them).  These use the full C names in an attempt to avoid namespace
conflicts.

  ZVT_TERM_DO_UTMP_LOG
  ZVT_TERM_DO_WTMP_LOG
  ZVT_TERM_DO_LASTLOG
    flags for $term->forkpty.

  ZVT_BACKGROUND_SHADED
  ZVT_BACKGROUND_SCROLL
    flags for $term->set_background; scroll cannot be used with
    transparency.

=head1 SEE ALSO

perl(1), Glib(3pm), Gtk2(3pm).

=head1 AUTHORS

muppet <scott at asofyet dot org>,
Leon Strong <leon dot strong at staff dot ihug dot co dot nz>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by the gtk2-perl team.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the 
Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
Boston, MA  02111-1307  USA.

=cut
